@@ -1,7 +1,7 @@
 package MooseX::AttributeHelpers::MethodProvider::Array;
 use Moose::Role;
 
-our $VERSION   = '0.17';
+our $VERSION   = '0.20';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -15,7 +15,7 @@ sub push : method {
         return sub { 
             my $instance = CORE::shift;
             $container_type_constraint->check($_) 
-                || confess "Value " . ($_||'undef') . " did not pass container type constraint"
+                || confess "Value " . ($_||'undef') . " did not pass container type constraint '$container_type_constraint'"
                     foreach @_;
             CORE::push @{$reader->($instance)} => @_; 
         };                    
@@ -42,7 +42,7 @@ sub unshift : method {
         return sub { 
             my $instance = CORE::shift;
             $container_type_constraint->check($_) 
-                || confess "Value " . ($_||'undef') . " did not pass container type constraint"
+                || confess "Value " . ($_||'undef') . " did not pass container type constraint '$container_type_constraint'"
                     foreach @_;
             CORE::unshift @{$reader->($instance)} => @_; 
         };                    
@@ -75,7 +75,7 @@ sub set : method {
         my $container_type_constraint = $attr->type_constraint->type_parameter;
         return sub { 
             ($container_type_constraint->check($_[2])) 
-                || confess "Value " . ($_[2]||'undef') . " did not pass container type constraint";
+                || confess "Value " . ($_[2]||'undef') . " did not pass container type constraint '$container_type_constraint'";
             $reader->($_[0])->[$_[1]] = $_[2]
         };                    
     }
@@ -86,6 +86,44 @@ sub set : method {
     }
 }
 
+sub accessor : method {
+    my ($attr, $reader, $writer) = @_;
+
+    if ($attr->has_type_constraint && $attr->type_constraint->isa('Moose::Meta::TypeConstraint::Parameterized')) {
+        my $container_type_constraint = $attr->type_constraint->type_parameter;
+        return sub {
+            my $self = shift;
+
+            if (@_ == 1) { # reader
+                return $reader->($self)->[$_[0]];
+            }
+            elsif (@_ == 2) { # writer
+                ($container_type_constraint->check($_[1]))
+                    || confess "Value " . ($_[1]||'undef') . " did not pass container type constraint '$container_type_constraint'";
+                $reader->($self)->[$_[0]] = $_[1];
+            }
+            else {
+                confess "One or two arguments expected, not " . @_;
+            }
+        };
+    }
+    else {
+        return sub {
+            my $self = shift;
+
+            if (@_ == 1) { # reader
+                return $reader->($self)->[$_[0]];
+            }
+            elsif (@_ == 2) { # writer
+                $reader->($self)->[$_[0]] = $_[1];
+            }
+            else {
+                confess "One or two arguments expected, not " . @_;
+            }
+        };
+    }
+}
+
 sub clear : method {
     my ($attr, $reader, $writer) = @_;
     return sub { 
@@ -106,7 +144,7 @@ sub insert : method {
         my $container_type_constraint = $attr->type_constraint->type_parameter;
         return sub { 
             ($container_type_constraint->check($_[2])) 
-                || confess "Value " . ($_[2]||'undef') . " did not pass container type constraint";
+                || confess "Value " . ($_[2]||'undef') . " did not pass container type constraint '$container_type_constraint'";
             CORE::splice @{$reader->($_[0])}, $_[1], 0, $_[2];
         };                    
     }
@@ -124,7 +162,7 @@ sub splice : method {
         return sub { 
             my ( $self, $i, $j, @elems ) = @_;
             ($container_type_constraint->check($_)) 
-                || confess "Value " . (defined($_) ? $_ : 'undef') . " did not pass container type constraint" for @elems;
+                || confess "Value " . (defined($_) ? $_ : 'undef') . " did not pass container type constraint '$container_type_constraint'" for @elems;
             CORE::splice @{$reader->($self)}, $i, $j, @elems;
         };                    
     }
@@ -214,6 +252,11 @@ You can provide an optional subroutine reference to sort with (as you
 can with the core C<sort> function). However, instead of using C<$a>
 and C<$b>, you will need to use C<$_[0]> and C<$_[1]> instead.
 
+=item B<accessor>
+
+If passed one argument, returns the value of the requested element.
+If passed two arguments, sets the value of the requested element.
+
 =back
 
 =head1 BUGS
@@ -228,7 +271,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+Copyright 2007-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
