@@ -1,7 +1,7 @@
 package MooseX::AttributeHelpers::Trait::Number;
 use Moose::Role;
 
-our $VERSION   = '0.19';
+our $VERSION   = '0.20';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -55,11 +55,6 @@ has 'method_constructors' => (
     
 no Moose::Role;
 
-# register the alias ...
-package # hide me from search.cpan.org
-    Moose::Meta::Attribute::Custom::Trait::Number;
-sub register_implementation { 'MooseX::AttributeHelpers::Trait::Number' }
-
 1;
 
 =pod
