@@ -2,7 +2,7 @@
 package MooseX::AttributeHelpers::Trait::String;
 use Moose::Role;
 
-our $VERSION   = '0.19';
+our $VERSION   = '0.20';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -47,11 +47,6 @@ after 'check_provides_values' => sub {
 
 no Moose::Role;
 
-# register the alias ...
-package # hide me from search.cpan.org
-    Moose::Meta::Attribute::Custom::Trait::String;
-sub register_implementation { 'MooseX::AttributeHelpers::Trait::String' }
-
 1;
 
 __END__
